@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## Asynchronous HTTP Request and Promise - ~/lib/HTTP/Promise/Body/Form.pm
-## Version v0.2.3
+## Version v0.2.4
 ## Copyright(c) 2025 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2022/05/18
@@ -16,12 +16,12 @@ BEGIN
 {
     use strict;
     use warnings;
-    use warnings::register;
+    warnings::register_categories( 'HTTP::Promise' );
     use parent qw( Module::Generic::Hash );
     use vars qw( $VERSION );
     # use Nice::Try;
     use URL::Encode::XS ();
-    our $VERSION = 'v0.2.3';
+    our $VERSION = 'v0.2.4';
 };
 
 use strict;
@@ -346,7 +346,7 @@ sub print
     return(1);
 }
 
-sub _is_warnings_enabled { return( warnings::enabled( $_[0] ) ); }
+sub _is_warnings_enabled { return( warnings::enabled( 'HTTP::Promise' ) ); }
 
 # NOTE: FREEZE is inherited
 
@@ -376,7 +376,7 @@ HTTP::Promise::Body::Form - x-www-form-urlencoded Data Class
 
 =head1 VERSION
 
-    v0.2.3
+    v0.2.4
 
 =head1 DESCRIPTION
 
